==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GtkToolkit__241PrepareImage.h <==
// class gnu.java.awt.peer.gtk.GtkToolkit$1PrepareImage

// class file dependencies
// @dep_class d016887310447e16 gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a3a7cdc3e4c7ce28 java_lang_Thread

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage_H_
#define _JC_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage_H_

// Forward structure declarations
struct _jc_gnu_java_awt_peer_gtk_GtkImage$object;
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit$object;
struct _jc_java_awt_image_ImageObserver$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$refs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$object	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vmethods	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vtable	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vtype	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$method$_init$9931782ff2413bc2(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$object *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit$object *, struct _jc_gnu_java_awt_peer_gtk_GtkImage$object *, struct _jc_object *);

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$method_info$run$8b940e4957c86ebf;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$object *);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vmethods	gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$sub_refs {
	struct _jc_gnu_java_awt_peer_gtk_GtkImage$object	*image;
	struct _jc_object	*observer;
	struct _jc_gnu_java_awt_peer_gtk_GtkToolkit$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$refs {
    _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$sub_refs	gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$sub_nonrefs	gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$object {
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vtype _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/peer/gtk/GtkToolkit__241PrepareImage.h <==
// class gnu.java.awt.peer.gtk.GtkToolkit$1PrepareImage

// class file dependencies
// @dep_class c887d5b6e6c8f17e gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7e33d4feabbc3f15 java_lang_Thread

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage_H_
#define _JC_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage_H_

// Forward structure declarations
struct _jc_gnu_java_awt_peer_gtk_GtkImage$object;
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit$object;
struct _jc_java_awt_image_ImageObserver$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$refs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$object	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vmethods	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vtable	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vtype	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$method$_init$9931782ff2413bc2(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$object *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit$object *, struct _jc_gnu_java_awt_peer_gtk_GtkImage$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$method_info$run$8b940e4957c86ebf;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vmethods	gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$sub_refs {
	struct _jc_gnu_java_awt_peer_gtk_GtkImage$object	*image;
	struct _jc_object	*observer;
	struct _jc_gnu_java_awt_peer_gtk_GtkToolkit$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$refs {
    _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$sub_refs	gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$sub_nonrefs	gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$object {
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$vtype _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkToolkit__241PrepareImage_H_ */
